@@ -1,18 +1,23 @@
 <?php
 
-/** @generate-function-entries */
+/**
+ * @generate-function-entries
+ * @generate-legacy-arginfo 70000
+ */
 
 class Imagick
 {
-#if MagickLibVersion > 0x628
-    public function optimizeImageLayers(): bool  {}
+
+    public function optimizeImageLayers(): Imagick {}
 
     // METRIC_*
     public function compareImageLayers(int $metric): Imagick  {}
 
     public function pingImageBlob(string $image): bool  {}
 
-    public function pingImageFile(resource $filehandle, ?string $filename = null): bool  {}
+    // $filehandle should be a resource, but that is a pseudo-type
+    // which causes problems for people trying to mock the class
+    public function pingImageFile(/*resource*/mixed $filehandle, ?string $filename = null): bool  {}
 
     public function transposeImage(): bool  {}
 
@@ -22,6 +27,14 @@ class Imagick
 
     public function waveImage(float $amplitude, float $length): bool  {}
 
+#if MagickLibVersion >= 0x700
+    public function waveImageWithMethod(
+        float $amplitude,
+        float $length,
+        int $interpolate_method // INTERPOLATE_*
+    ): bool  {}
+#endif
+
     public function vignetteImage(float $black_point, float $white_point, int $x, int $y): bool  {}
 
     public function uniqueImageColors(): bool  {}
@@ -77,8 +90,8 @@ class Imagick
         int $channel = Imagick::CHANNEL_DEFAULT
     ): bool  {}
 
-#if MagickLibVersion < 0x700
-    /** @deprecated */
+
+
     public function roundCornersImage(
         float $x_rounding,
         float $y_rounding,
@@ -86,9 +99,7 @@ class Imagick
         float $displace = 5,
         float $size_correction = -6): bool {}
 
-    /* This alias is due to BWC */
     /**
-     * @deprecated
      * @alias Imagick::roundCornersImage
      */
     public function roundCorners(
@@ -98,8 +109,6 @@ class Imagick
         float $displace = 5,
         float $size_correction = -6): bool {}
 
-#endif
-
     public function setIteratorIndex(int $index): bool  {}
 
     public function getIteratorIndex(): int  {}
@@ -108,13 +117,13 @@ class Imagick
     /** @deprecated */
     public function transformImage(string $crop, string $geometry): Imagick  {}
 #endif
-#endif
 
 #if MagickLibVersion > 0x630
 #if MagickLibVersion < 0x700
     /** @deprecated */
     public function setImageOpacity(float $opacity): bool  {}
 #endif
+#endif
 
 #if MagickLibVersion >= 0x700
     public function setImageAlpha(float $alpha): bool {}
@@ -128,10 +137,17 @@ class Imagick
         int $channel = Imagick::CHANNEL_DEFAULT
     ): bool  {}
 #endif
+
+#if MagickLibVersion >= 0x700
+    public function polaroidWithTextAndMethod(
+        ImagickDraw $settings,
+        float $angle,
+        string $caption,
+        int $method
+    ): bool {}
 #endif
 
-#if MagickLibVersion > 0x631
-    // TODO - ImagickDraw ....
+
     public function polaroidImage(ImagickDraw $settings, float $angle): bool  {}
 
     public function getImageProperty(string $name): string  {}
@@ -160,7 +176,7 @@ class Imagick
     public function getImageLength(): int  {}
 
     public function extentImage(int $width, int $height, int $x, int $y): bool  {}
-#endif
+
 #if MagickLibVersion > 0x633
     public function getImageOrientation(): int  {}
 
@@ -183,11 +199,15 @@ class Imagick
 #endif
 #endif
 
-#if MagickLibVersion > 0x635
-
-    // TODO - Imagick
     public function clutImage(Imagick $lookup_table, int $channel = Imagick::CHANNEL_DEFAULT): bool  {}
 
+#if MagickLibVersion >= 0x700
+    public function clutImageWithInterpolate(
+        Imagick $lookup_table,
+        int $pixel_interpolate_method // PixelInterpolateMethod
+    ): bool  {}
+#endif
+
     public function getImageProperties(string $pattern = "*", bool $include_values = true): array  {}
 
     public function getImageProfiles(string $pattern = "*", bool $include_values = true): array  {}
@@ -195,9 +215,13 @@ class Imagick
     // DISTORTION_*
     public function distortImage(int $distortion, array $arguments, bool $bestfit): bool  {}
 
-    public function writeImageFile(resource $filehandle, ?string $format = null): bool  {}
+    // $filehandle should be a resource, but that is a pseudo-type
+    // which causes problems for people trying to mock the class
+    public function writeImageFile(/*resource*/mixed $filehandle, ?string $format = null): bool  {}
 
-    public function writeImagesFile(resource $filehandle, ?string $format = null): bool  {}
+    // $filehandle should be a resource, but that is a pseudo-type
+    // which causes problems for people trying to mock the class
+    public function writeImagesFile(/*resource*/mixed $filehandle, ?string $format = null): bool  {}
 
     public function resetImagePage(string $page): bool  {}
 
@@ -218,7 +242,7 @@ class Imagick
     public function recolorImage(array $matrix): bool  {}
 #endif
 #endif
-#endif
+
 
 #if MagickLibVersion > 0x636
     public function setFont(string $font): bool  {}
@@ -273,7 +297,6 @@ class Imagick
 
     public function encipherImage(string $passphrase): bool  {}
 
-//    PHP_ME(imagick, decipherimage, imagick_decipherimage_args, ZEND_ACC_PUBLIC)
     public function decipherImage(string $passphrase): bool  {}
 #endif
 
@@ -287,7 +310,7 @@ class Imagick
     // CHANNEL_
     public function getImageChannelRange(int $channel): array  {}
 
-    public function getImageAlphaChannel(): int  {}
+    public function getImageAlphaChannel(): bool  {}
 #endif
 
 #if MagickLibVersion > 0x642
@@ -306,44 +329,28 @@ class Imagick
 #endif
 
 #if MagickLibVersion > 0x645
-    /**
-     * @param int $x
-     * @param int $y
-     * @param int $width
-     * @param int $height
-     * @param string $map
-     * @param int $pixelstorage // PIXELSTORAGE
-     * @param array $pixels
-     * @return bool
-     */
     public function importImagePixels(
         int $x,
         int $y,
         int $width,
         int $height,
         string $map,
-        int $pixelstorage,
+        int $pixelstorage, // PIXELSTORAGE
         array $pixels): bool {}
 
     public function deskewImage(float $threshold): bool  {}
 
-    /**
-     * @param int $colorspace // COLORSPACE
-     * @param float $cluster_threshold
-     * @param float $smooth_threshold
-     * @param bool $verbose
-     * @return bool
-     */
+
     public function segmentImage(
-        int $colorspace,
+        int $colorspace, // COLORSPACE
         float $cluster_threshold,
         float $smooth_threshold,
         bool $verbose = false
     ): bool  {}
 
-    // SPARSECOLORMETHOD_*
+
     public function sparseColorImage(
-        int $sparsecolormethod,
+        int $sparsecolormethod, // SPARSECOLORMETHOD_*
         array $arguments,
         int $channel = Imagick::CHANNEL_DEFAULT
     ): bool {}
@@ -357,22 +364,13 @@ class Imagick
 #endif
 
 #if MagickLibVersion > 0x646
-    /**
-     * @param int $x
-     * @param int $y
-     * @param int $width
-     * @param int $height
-     * @param string $map e.g. "RGB"
-     * @param int $pixelstorage // PIXELSTORAGE
-     * @return array
-     */
     public function exportImagePixels(
         int $x,
         int $y,
         int $width,
         int $height,
-        string $map,
-        int $pixelstorage
+        string $map, // e.g. "RGB"
+        int $pixelstorage // PIXELSTORAGE
     ): array {}
 #endif
 
@@ -403,17 +401,17 @@ class Imagick
 
 #if MagickLibVersion > 0x656
     /**
-     * @param string $artifact example 'compose:args'
-     * @return string
+     *  $artifact example 'compose:args'
+     *
      */
-    public function getImageArtifact(string $artifact): string  {}
+    public function getImageArtifact(string $artifact): string|null  {}
 
     /**
-     * @param string $artifact example 'compose:args'
-     * @param string $value example  "1,0,-0.5,0.5"
-     * @return bool
+     * $artifact example 'compose:args'
+     * $value example  "1,0,-0.5,0.5"
+     *
      */
-    public function setImageArtifact(string $artifact, string $value): bool  {}
+    public function setImageArtifact(string $artifact, string|null $value): bool  {}
 
     public function deleteImageArtifact(string $artifact): bool  {}
 
@@ -494,13 +492,8 @@ class Imagick
     public function clear(): bool  {}
 
     public function clone(): Imagick  {}
-        
-#if !defined(MAGICKCORE_EXCLUDE_DEPRECATED)
-#if MagickLibVersion < 0x700
-    /** @deprecated */
+
     public function getImageSize(): int  {}
-#endif
-#endif
 
     public function getImageBlob(): string  {}
 
@@ -520,15 +513,9 @@ class Imagick
 
     public function hasNextImage(): bool  {}
 
-#if !defined(MAGICKCORE_EXCLUDE_DEPRECATED)
-#if MagickLibVersion < 0x700
-    /** @deprecated */
     public function setImageIndex(int $index): bool  {}
 
-    /** @deprecated */
     public function getImageIndex(): int  {}
-#endif
-#endif
 
     public function commentImage(string $comment): bool  {}
 
@@ -568,21 +555,12 @@ class Imagick
     public function getImageColors(): int  {}
 
 
-
-    /**
-     * @param ImagickDraw $settings
-     * @param string $tile_geometry  e.g. "3x2+0+0"
-     * @param string $thumbnail_geometry e.g. "200x160+3+3>"
-     * @param int $monatgemode // MONTAGEMODE_
-     * @param string $frame // "10x10+2+2"
-     * @return Imagick
-     */
     public function montageImage(
         ImagickDraw $settings,
-        string $tile_geometry,
-        string $thumbnail_geometry,
-        int $monatgemode,
-        string $frame
+        string $tile_geometry, // e.g. "3x2+0+0"
+        string $thumbnail_geometry, // e.g. "200x160+3+3>"
+        int $monatgemode, // MONTAGEMODE_
+        string $frame // "10x10+2+2"
     ): Imagick {}
 
     public function identifyImage(bool $append_raw_output = false): array  {}
@@ -601,6 +579,10 @@ class Imagick
 
     public function normalizeImage(int $channel = Imagick::CHANNEL_DEFAULT): bool  {}
 
+#if MagickLibVersion >= 0x700
+    public function oilPaintImageWithSigma(float $radius, float $sigma): bool  {}
+#endif
+
     public function oilPaintImage(float $radius): bool  {}
 
     public function posterizeImage(int $levels, bool $dither): bool  {}
@@ -657,8 +639,8 @@ class Imagick
 
     public function setImageIterations(int $iterations): bool  {}
 
-#if MagickLibVersion < 0x700
-    /** @deprecated */
+
+#if MagickLibVersion < 0x700 || MagickLibVersion >= 0x705
     public function setImageMatteColor(ImagickPixel|string $matte_color): bool  {}
 #endif
 
@@ -693,7 +675,9 @@ class Imagick
 
     public function pingImage(string $filename): bool  {}
 
-    public function readImageFile(resource $filehandle, ?string $filename = null): bool  {}
+    // $filehandle should be a resource, but that is a pseudo-type
+    // which causes problems for people trying to mock the class
+    public function readImageFile(/*resource*/mixed $filehandle, ?string $filename = null): bool  {}
 
     public function displayImage(string $servername): bool  {}
 
@@ -701,8 +685,22 @@ class Imagick
 
     public function spreadImage(float $radius): bool  {}
 
+#if MagickLibVersion >= 0x700
+    public function spreadImageWithMethod(
+        float $radius,
+        int $interpolate_method // INTERPOLATE_*
+    ): bool  {}
+#endif
+
     public function swirlImage(float $degrees): bool  {}
 
+#if MagickLibVersion >= 0x700
+    public function swirlImageWithMethod(
+        float $degrees,
+        int $interpolate_method // INTERPOLATE_*
+    ): bool  {}
+#endif
+
     public function stripImage(): bool  {}
 
     public static function queryFormats(string $pattern = "*"): array  {}
@@ -717,6 +715,14 @@ class Imagick
     // NOISE_*
     public function addNoiseImage(int $noise, int $channel = Imagick::CHANNEL_DEFAULT): bool  {}
 
+#if IM_HAVE_IMAGICK_ADD_NOISE_WITH_ATTENUATE
+    public function addNoiseImageWithAttenuate(
+        int $noise,
+        float $attenuate,
+        int $channel = Imagick::CHANNEL_DEFAULT
+    ): bool  {}
+#endif
+
     public function motionBlurImage(
         float $radius,
         float $sigma,
@@ -737,14 +743,22 @@ class Imagick
 
     public function affineTransformImage(ImagickDraw $settings): bool  {}
 
-#if MagickLibVersion < 0x700
-#if !defined(MAGICKCORE_EXCLUDE_DEPRECATED)
-    /** @deprecated */
     public function averageImages(): Imagick  {}
-#endif
-#endif
 
-    public function borderImage(ImagickPixel|string $border_color, int $width, int $height): bool  {}
+    public function borderImage(
+        ImagickPixel|string $border_color,
+        int $width,
+        int $height
+    ): bool  {}
+
+#if MagickLibVersion >= 0x700
+    public function borderImageWithComposite(
+        ImagickPixel|string $border_color,
+        int $width,
+        int $height,
+        int $composite // COMPOSITE_ // null rather than OverCompositeOp as we don't control the value
+    ): bool  {}
+#endif
 
     public static function calculateCrop(
         int $original_width,
@@ -792,8 +806,12 @@ class Imagick
 
     public function combineImages(int $colorspace): Imagick  {}
 
+#if MagickLibVersion >= 0x700
+    public function convolveImage(ImagickKernel $kernel, int $channel = Imagick::CHANNEL_DEFAULT): bool  {}
+#else
     // kernel is a 2d array of float values
     public function convolveImage(array $kernel, int $channel = Imagick::CHANNEL_DEFAULT): bool  {}
+#endif
 
     public function cycleColormapImage(int $displace): bool  {}
 
@@ -817,16 +835,12 @@ class Imagick
 //http://www.imagemagick.org/Usage/layers/#evaluate-sequence
 
     // EVALUATE_*
-    public function evaluateImages(int $evaluate): bool {}
+    public function evaluateImages(int $evaluate): Imagick {}
 
 #endif
 
-#if MagickLibVersion < 0x700
-#if !defined(MAGICKCORE_EXCLUDE_DEPRECATED)
-    /** @deprecated */
     public function flattenImages(): Imagick  {}
-#endif
-#endif
+
     public function flipImage(): bool  {}
 
     public function flopImage(): bool  {}
@@ -843,6 +857,16 @@ class Imagick
         int $outer_bevel
     ): bool  {}
 
+#if MagickLibVersion >= 0x700
+    public function frameImageWithComposite(
+        ImagickPixel|string $matte_color,
+        int $width,
+        int $height,
+        int $inner_bevel,
+        int $outer_bevel,
+        int $composite
+    ): bool  {}
+#endif
 
     public function fxImage(string $expression, int $channel = Imagick::CHANNEL_DEFAULT): Imagick  {}
 
@@ -960,6 +984,13 @@ class Imagick
 
     public function implodeImage(float $radius): bool  {}
 
+#if MagickLibVersion >= 0x700
+	public function implodeImageWithMethod(
+		float $radius,
+		int $pixel_interpolate_method // PixelInterpolateMethod
+	): bool  {}
+#endif
+
 #if MagickLibVersion >= 0x658
     // TODO MagickWand *magnitude_wand,MagickWand *phase_wand,
     public function inverseFourierTransformImage(Imagick $complement, bool $magnitude): bool  {}
@@ -1017,9 +1048,9 @@ class Imagick
     // PREVIEW_*
     public function previewImages(int $preview): bool  {}
 
-    public function profileImage(string $name, string $profile): bool  {}
+    public function profileImage(string $name, ?string $profile): bool  {}
 
-    public function  quantizeImage(
+    public function quantizeImage(
         int $number_colors,
         int $colorspace,
         int $tree_depth,
@@ -1056,7 +1087,11 @@ class Imagick
     public function setImageBiasQuantum(string $bias): void  {}
 #endif
 
+#if MagickLibVersion >= 0x700
+    public function setImageBluePrimary(float $x, float $y, float $z): bool  {}
+#else
     public function setImageBluePrimary(float $x, float $y): bool  {}
+#endif
     /* {{{ proto bool Imagick::setImageBluePrimary(float x,float y)
 For IM7 the prototype is
 proto bool Imagick::setImageBluePrimary(float x, float y, float z) */
@@ -1073,21 +1108,33 @@ proto bool Imagick::setImageBluePrimary(float x, float y, float z) */
 
     public function setImageExtent(int $columns, int $rows): bool  {}
 
+#if MagickLibVersion >= 0x700
+    public function setImageGreenPrimary(float $x, float $y, float $z): bool  {}
+#else
     public function setImageGreenPrimary(float $x, float $y): bool  {}
+#endif
 
     // INTERLACE_*
     public function setImageInterlaceScheme(int $interlace): bool  {}
 
     public function setImageProfile(string $name, string $profile): bool  {}
 
+#if MagickLibVersion >= 0x700
+    public function setImageRedPrimary(float $x, float $y, float $z): bool  {}
+#else
     public function setImageRedPrimary(float $x, float $y): bool  {}
+#endif
 
     // RENDERINGINTENT
     public function setImageRenderingIntent(int $rendering_intent): bool  {}
 
     public function setImageVirtualPixelMethod(int $method): bool  {}
 
+#if MagickLibVersion >= 0x700
+    public function setImageWhitePoint(float $x, float $y, float $z): bool  {}
+#else
     public function setImageWhitePoint(float $x, float $y): bool  {}
+#endif
 
     public function  sigmoidalContrastImage(
         bool $sharpen,
@@ -1127,7 +1174,7 @@ proto bool Imagick::setImageBluePrimary(float x, float y, float z) */
         int $columns,
         int $rows,
         ImagickPixel|string $background_color,
-        string $format = null
+        ?string $format = null
     ): bool  {}
 
     // TODO - canvas? description
@@ -1139,8 +1186,10 @@ proto bool Imagick::setImageBluePrimary(float x, float y, float z) */
 
     public static function getCopyright(): string  {}
 
-    public static function getConfigureOptions(string $pattern = "*"): string {}
-
+    /**
+     * @return string[]
+     */
+    public static function getConfigureOptions(string $pattern = "*"): array {}
 
 #if MagickLibVersion > 0x660
     public static function getFeatures(): string {}
@@ -1172,7 +1221,7 @@ proto bool Imagick::setImageBluePrimary(float x, float y, float z) */
 
     public static function getResource(int $type): int  {}
 
-    public static function getResourceLimit(int $type): int  {}
+    public static function getResourceLimit(int $type): float  {}
 
     public function getSamplingFactors(): array  {}
 
@@ -1221,16 +1270,10 @@ proto bool Imagick::setImageBluePrimary(float x, float y, float z) */
 //    public function key(): int  {}
 //
 //# endif
-//#endif
+#endif
 
-    /** @alias Imagick::nextImage
-     *  @tentative-return-type
-     */
     public function next(): void  {}
 
-    /** @alias Imagick::setFirstIterator
-     *  @tentative-return-type
-     */
     public function rewind(): void  {}
 
     public function valid(): bool  {}
@@ -1270,29 +1313,30 @@ proto bool Imagick::setImageBluePrimary(float x, float y, float z) */
 #endif
 
 #if MagickLibVersion >= 0x652
-    public function subimageMatch(Imagick $image, ?array &$offset = null, ?float &$similarity = null, float $threshold = 0.0, int $metric = 0): Imagick  {}
+	/**
+	 * @param array $offset
+	 * @param float $similarity
+	 */
+    public function subimageMatch(Imagick $image, &$offset = null, &$similarity = null, float $threshold = 0.0, int $metric = 0): Imagick  {}
 
-    /** @alias Imagick::subimageMatch */
-    public function similarityimage(Imagick $image, ?array &$offset = null, ?float &$similarity = null, float $threshold = 0.0, int $metric = 0): Imagick  {}
+	/**
+	 * @alias Imagick::subimageMatch
+	 * @param array $offset
+	 * @param float $similarity
+	 */
+    public function similarityImage(Imagick $image, &$offset = null, &$similarity = null, float $threshold = 0.0, int $metric = 0): Imagick  {}
 #endif
 
     public static function setRegistry(string $key, string $value): bool  {}
 
-    public static function getRegistry(string $key): string  {}
+    public static function getRegistry(string $key): string|false  {}
 
     public static function listRegistry(): array {}
 
 #if MagickLibVersion >= 0x680
 
-    /**
-     * @param int $morphology MORPHOLOGY_*
-     * @param int $iterations
-     * @param ImagickKernel $kernel
-     * @param int $channel
-     * @return bool
-     */
     public function morphology(
-        int $morphology,
+        int $morphology, // MORPHOLOGY_*
         int $iterations,
         ImagickKernel $kernel,
         int $channel = Imagick::CHANNEL_DEFAULT
@@ -1312,7 +1356,7 @@ proto bool Imagick::setImageBluePrimary(float x, float y, float z) */
 
 #if MagickLibVersion > 0x676
     /**
-     * @param string $color_correction_collection
+     * $color_correction_collection example:
      * <ColorCorrectionCollection xmlns="urn:ASC:CDL:v1.2">
      * <ColorCorrection id="cc03345">
      * <SOPNode>
@@ -1326,7 +1370,6 @@ proto bool Imagick::setImageBluePrimary(float x, float y, float z) */
      * </ColorCorrection>
      * </ColorCorrectionCollection>
      *
-     * @return bool
      */
     public function colorDecisionListImage(string $color_correction_collection): bool {}
 #endif
@@ -1351,7 +1394,7 @@ proto bool Imagick::setImageBluePrimary(float x, float y, float z) */
 #endif
 
 #if MagickLibVersion >= 0x693
-    public function localContrastImage(float $radius, float $strength): void {}
+    public function localContrastImage(float $radius, float $strength): bool {}
 #endif
 
 #if MagickLibVersion >= 0x700
@@ -1383,4 +1426,250 @@ proto bool Imagick::setImageBluePrimary(float x, float y, float z) */
 //        int $y,
 //        bool $invert,
 //        int $channel = Imagick::CHANNEL_DEFAULT): null {}
+
+
+#if IM_HAVE_IMAGICK_CANNYEDGEIMAGE
+    public function cannyEdgeImage(
+        float $radius,
+        float $sigma,
+        float $lower_percent,
+        float $upper_percent
+    ): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_SETSEED
+	public static function setSeed(int $seed): void {}
+#endif
+
+#if IM_HAVE_IMAGICK_WAVELETDENOISEIMAGE
+	public function waveletDenoiseImage(float $threshold, float $softness): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_MEANSHIFTIMAGE
+	public function meanShiftImage(
+		int $width,
+		int $height,
+		float $color_distance
+	): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_KMEANSIMAGE
+	public function kmeansImage(
+		int $number_colors,
+		int $max_iterations,
+		float $tolerance
+	): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_RANGETHRESHOLDIMAGE
+	public function rangeThresholdImage(
+		float $low_black,
+		float $low_white,
+		float $high_white,
+		float $high_black
+	): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_AUTOTHRESHOLDIMAGE
+	// AUTO_THRESHOLD_*
+	public function autoThresholdImage(int $auto_threshold_method): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_BILATERALBLURIMAGE
+	public function bilateralBlurImage(
+		float $radius,
+		float $sigma,
+		float $intensity_sigma,
+		float $spatial_sigma
+	): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_CLAHEIMAGE
+	public function claheImage(
+		int $width,
+		int $height,
+		int $number_bins,
+		float $clip_limit
+	): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_CHANNELFXIMAGE
+	// MagickChannelFxImage() applies a channel expression to the specified image.
+	// The expression consists of one or more channels, either mnemonic or numeric
+	// (e.g. red, 1), separated by actions as follows:
+	//
+	//   <=>     exchange two channels (e.g. red<=>blue)
+	//   =>      transfer a channel to another (e.g. red=>green)
+	//   ,       separate channel operations (e.g. red, green)
+	//   |       read channels from next input image (e.g. red | green)
+	//   ;       write channels to next output image (e.g. red; green; blue)
+	public function channelFxImage(string $expression): Imagick {}
+#endif
+
+#if IM_HAVE_IMAGICK_COLORTHRESHOLDIMAGE
+	public function colorThresholdImage(
+		ImagickPixel|string $start_color,
+		ImagickPixel|string $stop_color
+	): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_COMPLEXIMAGES
+	// COMPLEX_OPERATOR_
+	public function complexImages(int $complex_operator): Imagick {}
+#endif
+
+#if IM_HAVE_IMAGICK_INTERPOLATIVERESIZEIMAGE
+	public function interpolativeResizeImage(
+		int $columns,
+		int $rows,
+		int $interpolate // INTERPOLATE_
+	): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_LEVELIMAGECOLORS
+	public function levelImageColors(
+		ImagickPixel|string $black_color,
+		ImagickPixel|string $white_color,
+		bool $invert
+	): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_LEVELIZEIMAGE
+	public function levelizeImage(
+		float $black_point,
+		float $gamma,
+		float $white_point
+	): bool {}
+#endif
+
+	//For example: "o3x3,6" generates a 6 level posterization of the image
+	// with a ordered 3x3 diffused pixel dither being applied between each
+	// level. While checker,8,8,4 will produce a 332 colormaped image with
+	// only a single checkerboard hash pattern (50% grey) between each color
+	// level, to basically double the number of color levels with a bare
+	// minimim of dithering.
+
+#if IM_HAVE_IMAGICK_ORDEREDDITHERIMAGE
+	public function orderedDitherImage(string $dither_format): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_WHITEBALANCEIMAGE
+	public function whiteBalanceImage(): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_DELETE_OPTION
+	public function deleteOption(string $option): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_BACKGROUND_COLOR
+	public function getBackgroundColor(): ImagickPixel {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_IMAGE_ARTIFACTS
+	/**
+	 * @return string[]
+	 */
+	public function getImageArtifacts(string $pattern = "*"): array {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_IMAGE_DISTORTIONS
+
+	/**
+	 * metric - MetricType_
+	 * @return float[]
+	 */
+//	public function getImageDistortions(int $metric): array{}
+//    for (j=0; j <= MaxPixelChannels; j++)
+//      distortion[j]+=channel_distortion[j];
+//	Use MagickRelinquishMemory() to free the metrics when you are done with them.
+#endif
+
+#if IM_HAVE_IMAGICK_GET_IMAGE_KURTOSIS
+
+	/**
+	 * return [kurtosis:float,skewness: float]
+	 */
+	public function getImageKurtosis(): array {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_IMAGE_MEAN
+	/**
+	 * return [$mean, $standard_deviation]
+	 */
+	public function getImageMean(): array {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_IMAGE_RANGE
+	/**
+	 * return [minima, float $maxima]
+	 */
+	public function getImageRange(): array {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_INTERPOLATE_METHOD
+	/**
+	 * return int - PixelInterpolateMethod
+	 */
+	public function getInterpolateMethod(): int {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_OPTIONS
+	/**
+	 * return string[]
+	 */
+	public function getOptions(string $pattern = "*"): array {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_ORIENTATION
+	/**
+	 * return int OrientationType
+	 */
+	public function getOrientation(): int {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_RESOLUTION
+	/**
+	 * return [x: float, y: float]
+	 */
+	public function getResolution(): array {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_TYPE
+	/**
+	 * return ImageType
+	 */
+	public function getType(): int {}
+#endif
+
+#if IM_HAVE_IMAGICK_POLYNOMIAL_IMAGE
+	//%    o number_terms: the number of terms in the list.  The actual list length
+	//%      is 2 x number_terms + 1 (the constant).
+	public function polynomialImage(array $terms): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_SET_DEPTH
+	public function setDepth(int $depth): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_SET_EXTRACT
+	//%  MagickSetExtract() sets the extract geometry before you read or write an
+	//%  image file.  Use it for inline cropping (e.g. 200x200+0+0) or resizing
+	//%  (e.g.200x200).
+	public function setExtract(string $geometry): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_SET_INTERPOLATE_METHOD
+/**
+ * int $method - PixelInterpolateMethod
+ */
+	public function setInterpolateMethod(int $method): bool{}
+#endif
+
+#if IM_HAVE_IMAGICK_SET_ORIENTATION
+	/**
+	 * $orientation - OrientationType
+	 */
+	public function setOrientation(int $orientation): bool {}
+#endif
+
 }
